@@ -243,6 +243,13 @@ impl Jobs {
             Self::Apptainer(app) => app.meta.namespace.clone(),
         }
     }
+
+    pub fn job_names(&self) -> Vec<&str> {
+        match self {
+            Self::Python(py) => py.description.jobs.iter().map(|job| job.name()).collect(),
+            Self::Apptainer(apt) => apt.description.jobs.iter().map(|job| job.name()).collect(),
+        }
+    }
 }
 
 impl Jobs {
