@@ -86,7 +86,7 @@ pub struct Deserialization {
 
 #[derive(Debug, thiserror::Error)]
 pub enum RunJobError {
-    #[error("could not create / edit the job run script ({path}) (this should not happen). Error: `{0}`")]
+    #[error("could not create / edit the job run script ({path}) (this should not happen). Error: `{full_error}`")]
     CreateFile {
         path: std::path::PathBuf,
         full_error: std::io::Error,
@@ -279,6 +279,8 @@ pub enum AddError {
     FailedToAdd,
     #[error("There were no actual jobs specified in the configuration file")]
     NoJobsToAdd,
+    #[error("Duplicate job name `{0}` appeared in config file. Job names must be unique")]
+    DuplicateJobName(String),
 }
 
 #[derive(Debug, From, thiserror::Error)]
